<?php
/**
 * This file is part of Gutenberg Tabs.
 *
 * Gutenberg Tabs is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 2 of the License, or any later version.
 *
 * Gutenberg Tabs is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * Gutenberg Tabs.  If not, see <https://www.gnu.org/licenses/>.
 */

declare( strict_types=1 );

namespace GutenbergTabs;

/**
 * Tabs Block.
 *
 * @since 20211010
 */
class Block {
	private const EDITOR_SCRIPT = 'gutenberg-tabs-editor';
	private const EDITOR_STYLE = 'gutenberg-tabs-editor';
	private const FRONT_SCRIPT = 'gutenberg-tabs-front';
	private const FRONT_STYLE = 'gutenberg-tabs-front';

	/**
	 * The path to the plugin’s root file.
	 *
	 * @var string
	 */
	private string $plugin_file;

	/**
	 * Block constructor.
	 *
	 * @param string $plugin_file The path to the plugin’s root file.
	 *
	 * @since 20211010
	 */
	public function __construct( string $plugin_file ) {
		$this->plugin_file = $plugin_file;

		add_action( 'init', [ $this, 'register' ] );
	}

	/**
	 * Registers tho block to WordPress.
	 *
	 * @since 20211010
	 */
	public function register() {
		$assets = include plugin_dir_path( $this->plugin_file ) . 'build/index.asset.php';

		wp_register_script(
			self::EDITOR_SCRIPT,
			plugins_url( 'build/index.js', $this->plugin_file ),
			$assets['dependencies'],
			$assets['version'],
			true
		);

		wp_set_script_translations(
			self::EDITOR_SCRIPT,
			'gutenberg-tabs',
			plugin_dir_path( $this->plugin_file ) . 'languages'
		);

		wp_register_style(
			self::EDITOR_STYLE,
			plugins_url( 'build/index.css', $this->plugin_file ),
			[],
			$assets['version']
		);

		wp_register_script(
			self::FRONT_SCRIPT,
			plugins_url( 'src/tabs.js', $this->plugin_file ),
			[
				'jquery-core',
				'jquery-ui-tabs',
			],
			'20211011',
			true
		);

		wp_register_style(
			self::FRONT_STYLE,
			plugins_url( 'src/tabs.css', $this->plugin_file ),
			[],
			'20211011'
		);

		register_block_type(
			'tandem/tabs',
			[
				'style' => self::FRONT_STYLE,
				'script' => self::FRONT_SCRIPT,
				'editor_script' => self::EDITOR_SCRIPT,
				'editor_style' => self::EDITOR_STYLE,
			]
		);
	}

}
